# Welcome to AiiDA GUI!
[![PyPI version](https://badge.fury.io/py/aiida-gui.svg)](https://badge.fury.io/py/aiida-gui)
[![Docs status](https://readthedocs.org/projects/aiida-gui/badge)](http://aiida-gui.readthedocs.io/)
[![Unit test](https://github.com/aiidateam/aiida-gui/actions/workflows/ci.yml/badge.svg)](https://github.com/aiidateam/aiida-gui/actions/workflows/ci.yml)


Web UI to visualize and manage the AiiDA WorkGraph.


## Installation

```bash
pip install aiida-gui
````

## Usage

Start the AiiDA GUI server with the following command:

```bash
aiida-gui start
```

Open `http://localhost:8000` to access the AiiDA GUI in your web browser.

Stop the AiiDA GUI server with the following command:

```bash
aiida-gui stop
```
